Skip to contents

This function checks if there are any NAs in a specified column of a data frame.

Usage

check_nas(data, column)

Arguments

data

tibble or data frame

column

column to check for NAs

Value

stops if there are NAs in the column or if the column does not exist