Plot prior and posteriors of sigmas from hierarchical models
Source:R/prior_post.R
plot_prior_post_sigmas_localhierarchy.RdThis function plots the prior and posterior densities of sigma_estimate parameters.
R/prior_post.R
plot_prior_post_sigmas_localhierarchy.RdThis function plots the prior and posterior densities of sigma_estimate parameters.