R/check_nas.R
check_nas.Rd
This function checks if there are any NAs in a specified column of a data frame.
check_nas(data, column)
tibble or data frame
column to check for NAs
stops if there are NAs in the column or if the column does not exist