Create list with information including a model matrix, associated with the geo_unit_data and hierarchical_levels
Value
A list with components modelmatrix, assign, and index:
modelmatrix: A matrix where each column refers to one eta (number of rows equals number of lowest level units).assign: Integer vector of length equal to the number of etas;0for the intercept, then a hierarchical level index (starting at 2) for each eta level.index: A tibble withn_etarows, and columns:i: Index of etacolumn: Hierarchical levellevel: Name of hierarchical level
All components are associated with the provided geo_unit_data and hierarchical_levels.